# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.api.live_chat_bans_api import LiveChatBansApi


class TestLiveChatBansApi(unittest.TestCase):
    """LiveChatBansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LiveChatBansApi()

    def tearDown(self) -> None:
        pass

    def test_youtube_live_chat_bans_delete(self) -> None:
        """Test case for youtube_live_chat_bans_delete

        """
        pass

    def test_youtube_live_chat_bans_insert(self) -> None:
        """Test case for youtube_live_chat_bans_insert

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.member_snippet import MemberSnippet

class TestMemberSnippet(unittest.TestCase):
    """MemberSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MemberSnippet:
        """Test MemberSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MemberSnippet`
        """
        model = MemberSnippet()
        if include_optional:
            return MemberSnippet(
                creator_channel_id = '',
                member_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                    channel_id = '', 
                    channel_url = '', 
                    display_name = '', 
                    profile_image_url = '', ),
                memberships_details = youtube_ti.models.memberships_details.MembershipsDetails(
                    accessible_levels = [
                        ''
                        ], 
                    highest_accessible_level = '', 
                    highest_accessible_level_display_name = '', 
                    memberships_duration = youtube_ti.models.memberships_duration.MembershipsDuration(
                        member_since = '', 
                        member_total_duration_months = 56, ), 
                    memberships_duration_at_levels = [
                        youtube_ti.models.memberships_duration_at_level.MembershipsDurationAtLevel(
                            level = '', 
                            member_since = '', 
                            member_total_duration_months = 56, )
                        ], )
            )
        else:
            return MemberSnippet(
        )
        """

    def testMemberSnippet(self):
        """Test MemberSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ContentRating(BaseModel):
    """
    Ratings schemes. The country-specific ratings are mostly for movies and shows. LINT.IfChange
    """ # noqa: E501
    acb_rating: Optional[StrictStr] = Field(default=None, description="The video's Australian Classification Board (ACB) or Australian Communications and Media Authority (ACMA) rating. ACMA ratings are used to classify children's television programming.", alias="acbRating")
    agcom_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Italy's Autorità per le Garanzie nelle Comunicazioni (AGCOM).", alias="agcomRating")
    anatel_rating: Optional[StrictStr] = Field(default=None, description="The video's Anatel (Asociación Nacional de Televisión) rating for Chilean television.", alias="anatelRating")
    bbfc_rating: Optional[StrictStr] = Field(default=None, description="The video's British Board of Film Classification (BBFC) rating.", alias="bbfcRating")
    bfvc_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Thailand's Board of Film and Video Censors.", alias="bfvcRating")
    bmukk_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Austrian Board of Media Classification (Bundesministerium für Unterricht, Kunst und Kultur).", alias="bmukkRating")
    catv_rating: Optional[StrictStr] = Field(default=None, description="Rating system for Canadian TV - Canadian TV Classification System The video's rating from the Canadian Radio-Television and Telecommunications Commission (CRTC) for Canadian English-language broadcasts. For more information, see the Canadian Broadcast Standards Council website.", alias="catvRating")
    catvfr_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Canadian Radio-Television and Telecommunications Commission (CRTC) for Canadian French-language broadcasts. For more information, see the Canadian Broadcast Standards Council website.", alias="catvfrRating")
    cbfc_rating: Optional[StrictStr] = Field(default=None, description="The video's Central Board of Film Certification (CBFC - India) rating.", alias="cbfcRating")
    ccc_rating: Optional[StrictStr] = Field(default=None, description="The video's Consejo de Calificación Cinematográfica (Chile) rating.", alias="cccRating")
    cce_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Portugal's Comissão de Classificação de Espect´culos.", alias="cceRating")
    chfilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Switzerland.", alias="chfilmRating")
    chvrs_rating: Optional[StrictStr] = Field(default=None, description="The video's Canadian Home Video Rating System (CHVRS) rating.", alias="chvrsRating")
    cicf_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Commission de Contrôle des Films (Belgium).", alias="cicfRating")
    cna_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Romania's CONSILIUL NATIONAL AL AUDIOVIZUALULUI (CNA).", alias="cnaRating")
    cnc_rating: Optional[StrictStr] = Field(default=None, description="Rating system in France - Commission de classification cinematographique", alias="cncRating")
    csa_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from France's Conseil supérieur de l’audiovisuel, which rates broadcast content.", alias="csaRating")
    cscf_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Luxembourg's Commission de surveillance de la classification des films (CSCF).", alias="cscfRating")
    czfilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in the Czech Republic.", alias="czfilmRating")
    djctq_rating: Optional[StrictStr] = Field(default=None, description="The video's Departamento de Justiça, Classificação, Qualificação e Títulos (DJCQT - Brazil) rating.", alias="djctqRating")
    djctq_rating_reasons: Optional[List[StrictStr]] = Field(default=None, description="Reasons that explain why the video received its DJCQT (Brazil) rating.", alias="djctqRatingReasons")
    ecbmct_rating: Optional[StrictStr] = Field(default=None, description="Rating system in Turkey - Evaluation and Classification Board of the Ministry of Culture and Tourism", alias="ecbmctRating")
    eefilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Estonia.", alias="eefilmRating")
    egfilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Egypt.", alias="egfilmRating")
    eirin_rating: Optional[StrictStr] = Field(default=None, description="The video's Eirin (映倫) rating. Eirin is the Japanese rating system.", alias="eirinRating")
    fcbm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Malaysia's Film Censorship Board.", alias="fcbmRating")
    fco_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Hong Kong's Office for Film, Newspaper and Article Administration.", alias="fcoRating")
    fmoc_rating: Optional[StrictStr] = Field(default=None, description="This property has been deprecated. Use the contentDetails.contentRating.cncRating instead.", alias="fmocRating")
    fpb_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from South Africa's Film and Publication Board.", alias="fpbRating")
    fpb_rating_reasons: Optional[List[StrictStr]] = Field(default=None, description="Reasons that explain why the video received its FPB (South Africa) rating.", alias="fpbRatingReasons")
    fsk_rating: Optional[StrictStr] = Field(default=None, description="The video's Freiwillige Selbstkontrolle der Filmwirtschaft (FSK - Germany) rating.", alias="fskRating")
    grfilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Greece.", alias="grfilmRating")
    icaa_rating: Optional[StrictStr] = Field(default=None, description="The video's Instituto de la Cinematografía y de las Artes Audiovisuales (ICAA - Spain) rating.", alias="icaaRating")
    ifco_rating: Optional[StrictStr] = Field(default=None, description="The video's Irish Film Classification Office (IFCO - Ireland) rating. See the IFCO website for more information.", alias="ifcoRating")
    ilfilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Israel.", alias="ilfilmRating")
    incaa_rating: Optional[StrictStr] = Field(default=None, description="The video's INCAA (Instituto Nacional de Cine y Artes Audiovisuales - Argentina) rating.", alias="incaaRating")
    kfcb_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Kenya Film Classification Board.", alias="kfcbRating")
    kijkwijzer_rating: Optional[StrictStr] = Field(default=None, description="The video's NICAM/Kijkwijzer rating from the Nederlands Instituut voor de Classificatie van Audiovisuele Media (Netherlands).", alias="kijkwijzerRating")
    kmrb_rating: Optional[StrictStr] = Field(default=None, description="The video's Korea Media Rating Board (영상물등급위원회) rating. The KMRB rates videos in South Korea.", alias="kmrbRating")
    lsf_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Indonesia's Lembaga Sensor Film.", alias="lsfRating")
    mccaa_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Malta's Film Age-Classification Board.", alias="mccaaRating")
    mccyp_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Danish Film Institute's (Det Danske Filminstitut) Media Council for Children and Young People.", alias="mccypRating")
    mcst_rating: Optional[StrictStr] = Field(default=None, description="The video's rating system for Vietnam - MCST", alias="mcstRating")
    mda_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Singapore's Media Development Authority (MDA) and, specifically, it's Board of Film Censors (BFC).", alias="mdaRating")
    medietilsynet_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Medietilsynet, the Norwegian Media Authority.", alias="medietilsynetRating")
    meku_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Finland's Kansallinen Audiovisuaalinen Instituutti (National Audiovisual Institute).", alias="mekuRating")
    mena_mpaa_rating: Optional[StrictStr] = Field(default=None, description="The rating system for MENA countries, a clone of MPAA. It is needed to prevent titles go live w/o additional QC check, since some of them can be inappropriate for the countries at all. See b/33408548 for more details.", alias="menaMpaaRating")
    mibac_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Ministero dei Beni e delle Attività Culturali e del Turismo (Italy).", alias="mibacRating")
    moc_rating: Optional[StrictStr] = Field(default=None, description="The video's Ministerio de Cultura (Colombia) rating.", alias="mocRating")
    moctw_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Taiwan's Ministry of Culture (文化部).", alias="moctwRating")
    mpaa_rating: Optional[StrictStr] = Field(default=None, description="The video's Motion Picture Association of America (MPAA) rating.", alias="mpaaRating")
    mpaat_rating: Optional[StrictStr] = Field(default=None, description="The rating system for trailer, DVD, and Ad in the US. See http://movielabs.com/md/ratings/v2.3/html/US_MPAAT_Ratings.html.", alias="mpaatRating")
    mtrcb_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Movie and Television Review and Classification Board (Philippines).", alias="mtrcbRating")
    nbc_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Maldives National Bureau of Classification.", alias="nbcRating")
    nbcpl_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Poland.", alias="nbcplRating")
    nfrc_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Bulgarian National Film Center.", alias="nfrcRating")
    nfvcb_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Nigeria's National Film and Video Censors Board.", alias="nfvcbRating")
    nkclv_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Nacionãlais Kino centrs (National Film Centre of Latvia).", alias="nkclvRating")
    nmc_rating: Optional[StrictStr] = Field(default=None, description="The National Media Council ratings system for United Arab Emirates.", alias="nmcRating")
    oflc_rating: Optional[StrictStr] = Field(default=None, description="The video's Office of Film and Literature Classification (OFLC - New Zealand) rating.", alias="oflcRating")
    pefilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Peru.", alias="pefilmRating")
    rcnof_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from the Hungarian Nemzeti Filmiroda, the Rating Committee of the National Office of Film.", alias="rcnofRating")
    resorteviolencia_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Venezuela.", alias="resorteviolenciaRating")
    rtc_rating: Optional[StrictStr] = Field(default=None, description="The video's General Directorate of Radio, Television and Cinematography (Mexico) rating.", alias="rtcRating")
    rte_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Ireland's Raidió Teilifís Éireann.", alias="rteRating")
    russia_rating: Optional[StrictStr] = Field(default=None, description="The video's National Film Registry of the Russian Federation (MKRF - Russia) rating.", alias="russiaRating")
    skfilm_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Slovakia.", alias="skfilmRating")
    smais_rating: Optional[StrictStr] = Field(default=None, description="The video's rating in Iceland.", alias="smaisRating")
    smsa_rating: Optional[StrictStr] = Field(default=None, description="The video's rating from Statens medieråd (Sweden's National Media Council).", alias="smsaRating")
    tvpg_rating: Optional[StrictStr] = Field(default=None, description="The video's TV Parental Guidelines (TVPG) rating.", alias="tvpgRating")
    yt_rating: Optional[StrictStr] = Field(default=None, description="A rating that YouTube uses to identify age-restricted content.", alias="ytRating")
    __properties: ClassVar[List[str]] = ["acbRating", "agcomRating", "anatelRating", "bbfcRating", "bfvcRating", "bmukkRating", "catvRating", "catvfrRating", "cbfcRating", "cccRating", "cceRating", "chfilmRating", "chvrsRating", "cicfRating", "cnaRating", "cncRating", "csaRating", "cscfRating", "czfilmRating", "djctqRating", "djctqRatingReasons", "ecbmctRating", "eefilmRating", "egfilmRating", "eirinRating", "fcbmRating", "fcoRating", "fmocRating", "fpbRating", "fpbRatingReasons", "fskRating", "grfilmRating", "icaaRating", "ifcoRating", "ilfilmRating", "incaaRating", "kfcbRating", "kijkwijzerRating", "kmrbRating", "lsfRating", "mccaaRating", "mccypRating", "mcstRating", "mdaRating", "medietilsynetRating", "mekuRating", "menaMpaaRating", "mibacRating", "mocRating", "moctwRating", "mpaaRating", "mpaatRating", "mtrcbRating", "nbcRating", "nbcplRating", "nfrcRating", "nfvcbRating", "nkclvRating", "nmcRating", "oflcRating", "pefilmRating", "rcnofRating", "resorteviolenciaRating", "rtcRating", "rteRating", "russiaRating", "skfilmRating", "smaisRating", "smsaRating", "tvpgRating", "ytRating"]

    @field_validator('acb_rating')
    def acb_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['acbUnspecified', 'acbE', 'acbP', 'acbC', 'acbG', 'acbPg', 'acbM', 'acbMa15plus', 'acbR18plus', 'acbUnrated']):
            raise ValueError("must be one of enum values ('acbUnspecified', 'acbE', 'acbP', 'acbC', 'acbG', 'acbPg', 'acbM', 'acbMa15plus', 'acbR18plus', 'acbUnrated')")
        return value

    @field_validator('agcom_rating')
    def agcom_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['agcomUnspecified', 'agcomT', 'agcomVm14', 'agcomVm18', 'agcomUnrated']):
            raise ValueError("must be one of enum values ('agcomUnspecified', 'agcomT', 'agcomVm14', 'agcomVm18', 'agcomUnrated')")
        return value

    @field_validator('anatel_rating')
    def anatel_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['anatelUnspecified', 'anatelF', 'anatelI', 'anatelI7', 'anatelI10', 'anatelI12', 'anatelR', 'anatelA', 'anatelUnrated']):
            raise ValueError("must be one of enum values ('anatelUnspecified', 'anatelF', 'anatelI', 'anatelI7', 'anatelI10', 'anatelI12', 'anatelR', 'anatelA', 'anatelUnrated')")
        return value

    @field_validator('bbfc_rating')
    def bbfc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['bbfcUnspecified', 'bbfcU', 'bbfcPg', 'bbfc12a', 'bbfc12', 'bbfc15', 'bbfc18', 'bbfcR18', 'bbfcUnrated']):
            raise ValueError("must be one of enum values ('bbfcUnspecified', 'bbfcU', 'bbfcPg', 'bbfc12a', 'bbfc12', 'bbfc15', 'bbfc18', 'bbfcR18', 'bbfcUnrated')")
        return value

    @field_validator('bfvc_rating')
    def bfvc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['bfvcUnspecified', 'bfvcG', 'bfvcE', 'bfvc13', 'bfvc15', 'bfvc18', 'bfvc20', 'bfvcB', 'bfvcUnrated']):
            raise ValueError("must be one of enum values ('bfvcUnspecified', 'bfvcG', 'bfvcE', 'bfvc13', 'bfvc15', 'bfvc18', 'bfvc20', 'bfvcB', 'bfvcUnrated')")
        return value

    @field_validator('bmukk_rating')
    def bmukk_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['bmukkUnspecified', 'bmukkAa', 'bmukk6', 'bmukk8', 'bmukk10', 'bmukk12', 'bmukk14', 'bmukk16', 'bmukkUnrated']):
            raise ValueError("must be one of enum values ('bmukkUnspecified', 'bmukkAa', 'bmukk6', 'bmukk8', 'bmukk10', 'bmukk12', 'bmukk14', 'bmukk16', 'bmukkUnrated')")
        return value

    @field_validator('catv_rating')
    def catv_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['catvUnspecified', 'catvC', 'catvC8', 'catvG', 'catvPg', 'catv14plus', 'catv18plus', 'catvUnrated', 'catvE']):
            raise ValueError("must be one of enum values ('catvUnspecified', 'catvC', 'catvC8', 'catvG', 'catvPg', 'catv14plus', 'catv18plus', 'catvUnrated', 'catvE')")
        return value

    @field_validator('catvfr_rating')
    def catvfr_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['catvfrUnspecified', 'catvfrG', 'catvfr8plus', 'catvfr13plus', 'catvfr16plus', 'catvfr18plus', 'catvfrUnrated', 'catvfrE']):
            raise ValueError("must be one of enum values ('catvfrUnspecified', 'catvfrG', 'catvfr8plus', 'catvfr13plus', 'catvfr16plus', 'catvfr18plus', 'catvfrUnrated', 'catvfrE')")
        return value

    @field_validator('cbfc_rating')
    def cbfc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cbfcUnspecified', 'cbfcU', 'cbfcUA', 'cbfcUA7plus', 'cbfcUA13plus', 'cbfcUA16plus', 'cbfcA', 'cbfcS', 'cbfcUnrated']):
            raise ValueError("must be one of enum values ('cbfcUnspecified', 'cbfcU', 'cbfcUA', 'cbfcUA7plus', 'cbfcUA13plus', 'cbfcUA16plus', 'cbfcA', 'cbfcS', 'cbfcUnrated')")
        return value

    @field_validator('ccc_rating')
    def ccc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cccUnspecified', 'cccTe', 'ccc6', 'ccc14', 'ccc18', 'ccc18v', 'ccc18s', 'cccUnrated']):
            raise ValueError("must be one of enum values ('cccUnspecified', 'cccTe', 'ccc6', 'ccc14', 'ccc18', 'ccc18v', 'ccc18s', 'cccUnrated')")
        return value

    @field_validator('cce_rating')
    def cce_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cceUnspecified', 'cceM4', 'cceM6', 'cceM12', 'cceM16', 'cceM18', 'cceUnrated', 'cceM14']):
            raise ValueError("must be one of enum values ('cceUnspecified', 'cceM4', 'cceM6', 'cceM12', 'cceM16', 'cceM18', 'cceUnrated', 'cceM14')")
        return value

    @field_validator('chfilm_rating')
    def chfilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['chfilmUnspecified', 'chfilm0', 'chfilm6', 'chfilm12', 'chfilm16', 'chfilm18', 'chfilmUnrated']):
            raise ValueError("must be one of enum values ('chfilmUnspecified', 'chfilm0', 'chfilm6', 'chfilm12', 'chfilm16', 'chfilm18', 'chfilmUnrated')")
        return value

    @field_validator('chvrs_rating')
    def chvrs_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['chvrsUnspecified', 'chvrsG', 'chvrsPg', 'chvrs14a', 'chvrs18a', 'chvrsR', 'chvrsE', 'chvrsUnrated']):
            raise ValueError("must be one of enum values ('chvrsUnspecified', 'chvrsG', 'chvrsPg', 'chvrs14a', 'chvrs18a', 'chvrsR', 'chvrsE', 'chvrsUnrated')")
        return value

    @field_validator('cicf_rating')
    def cicf_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cicfUnspecified', 'cicfE', 'cicfKtEa', 'cicfKntEna', 'cicfUnrated']):
            raise ValueError("must be one of enum values ('cicfUnspecified', 'cicfE', 'cicfKtEa', 'cicfKntEna', 'cicfUnrated')")
        return value

    @field_validator('cna_rating')
    def cna_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cnaUnspecified', 'cnaAp', 'cna12', 'cna15', 'cna18', 'cna18plus', 'cnaUnrated']):
            raise ValueError("must be one of enum values ('cnaUnspecified', 'cnaAp', 'cna12', 'cna15', 'cna18', 'cna18plus', 'cnaUnrated')")
        return value

    @field_validator('cnc_rating')
    def cnc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cncUnspecified', 'cncT', 'cnc10', 'cnc12', 'cnc16', 'cnc18', 'cncE', 'cncInterdiction', 'cncUnrated']):
            raise ValueError("must be one of enum values ('cncUnspecified', 'cncT', 'cnc10', 'cnc12', 'cnc16', 'cnc18', 'cncE', 'cncInterdiction', 'cncUnrated')")
        return value

    @field_validator('csa_rating')
    def csa_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['csaUnspecified', 'csaT', 'csa10', 'csa12', 'csa16', 'csa18', 'csaInterdiction', 'csaUnrated']):
            raise ValueError("must be one of enum values ('csaUnspecified', 'csaT', 'csa10', 'csa12', 'csa16', 'csa18', 'csaInterdiction', 'csaUnrated')")
        return value

    @field_validator('cscf_rating')
    def cscf_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cscfUnspecified', 'cscfAl', 'cscfA', 'cscf6', 'cscf9', 'cscf12', 'cscf16', 'cscf18', 'cscfUnrated']):
            raise ValueError("must be one of enum values ('cscfUnspecified', 'cscfAl', 'cscfA', 'cscf6', 'cscf9', 'cscf12', 'cscf16', 'cscf18', 'cscfUnrated')")
        return value

    @field_validator('czfilm_rating')
    def czfilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['czfilmUnspecified', 'czfilmU', 'czfilm12', 'czfilm14', 'czfilm18', 'czfilmUnrated']):
            raise ValueError("must be one of enum values ('czfilmUnspecified', 'czfilmU', 'czfilm12', 'czfilm14', 'czfilm18', 'czfilmUnrated')")
        return value

    @field_validator('djctq_rating')
    def djctq_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['djctqUnspecified', 'djctqL', 'djctq10', 'djctq12', 'djctq14', 'djctq16', 'djctq18', 'djctqEr', 'djctqL10', 'djctqL12', 'djctqL14', 'djctqL16', 'djctqL18', 'djctq1012', 'djctq1014', 'djctq1016', 'djctq1018', 'djctq1214', 'djctq1216', 'djctq1218', 'djctq1416', 'djctq1418', 'djctq1618', 'djctqUnrated']):
            raise ValueError("must be one of enum values ('djctqUnspecified', 'djctqL', 'djctq10', 'djctq12', 'djctq14', 'djctq16', 'djctq18', 'djctqEr', 'djctqL10', 'djctqL12', 'djctqL14', 'djctqL16', 'djctqL18', 'djctq1012', 'djctq1014', 'djctq1016', 'djctq1018', 'djctq1214', 'djctq1216', 'djctq1218', 'djctq1416', 'djctq1418', 'djctq1618', 'djctqUnrated')")
        return value

    @field_validator('djctq_rating_reasons')
    def djctq_rating_reasons_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['djctqRatingReasonUnspecified', 'djctqViolence', 'djctqExtremeViolence', 'djctqSexualContent', 'djctqNudity', 'djctqSex', 'djctqExplicitSex', 'djctqDrugs', 'djctqLegalDrugs', 'djctqIllegalDrugs', 'djctqInappropriateLanguage', 'djctqCriminalActs', 'djctqImpactingContent']):
                raise ValueError("each list item must be one of ('djctqRatingReasonUnspecified', 'djctqViolence', 'djctqExtremeViolence', 'djctqSexualContent', 'djctqNudity', 'djctqSex', 'djctqExplicitSex', 'djctqDrugs', 'djctqLegalDrugs', 'djctqIllegalDrugs', 'djctqInappropriateLanguage', 'djctqCriminalActs', 'djctqImpactingContent')")
        return value

    @field_validator('ecbmct_rating')
    def ecbmct_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ecbmctUnspecified', 'ecbmctG', 'ecbmct7a', 'ecbmct7plus', 'ecbmct13a', 'ecbmct13plus', 'ecbmct15a', 'ecbmct15plus', 'ecbmct18plus', 'ecbmctUnrated']):
            raise ValueError("must be one of enum values ('ecbmctUnspecified', 'ecbmctG', 'ecbmct7a', 'ecbmct7plus', 'ecbmct13a', 'ecbmct13plus', 'ecbmct15a', 'ecbmct15plus', 'ecbmct18plus', 'ecbmctUnrated')")
        return value

    @field_validator('eefilm_rating')
    def eefilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['eefilmUnspecified', 'eefilmPere', 'eefilmL', 'eefilmMs6', 'eefilmK6', 'eefilmMs12', 'eefilmK12', 'eefilmK14', 'eefilmK16', 'eefilmUnrated']):
            raise ValueError("must be one of enum values ('eefilmUnspecified', 'eefilmPere', 'eefilmL', 'eefilmMs6', 'eefilmK6', 'eefilmMs12', 'eefilmK12', 'eefilmK14', 'eefilmK16', 'eefilmUnrated')")
        return value

    @field_validator('egfilm_rating')
    def egfilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['egfilmUnspecified', 'egfilmGn', 'egfilm18', 'egfilmBn', 'egfilmUnrated']):
            raise ValueError("must be one of enum values ('egfilmUnspecified', 'egfilmGn', 'egfilm18', 'egfilmBn', 'egfilmUnrated')")
        return value

    @field_validator('eirin_rating')
    def eirin_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['eirinUnspecified', 'eirinG', 'eirinPg12', 'eirinR15plus', 'eirinR18plus', 'eirinUnrated']):
            raise ValueError("must be one of enum values ('eirinUnspecified', 'eirinG', 'eirinPg12', 'eirinR15plus', 'eirinR18plus', 'eirinUnrated')")
        return value

    @field_validator('fcbm_rating')
    def fcbm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fcbmUnspecified', 'fcbmU', 'fcbmPg13', 'fcbmP13', 'fcbm18', 'fcbm18sx', 'fcbm18pa', 'fcbm18sg', 'fcbm18pl', 'fcbmUnrated']):
            raise ValueError("must be one of enum values ('fcbmUnspecified', 'fcbmU', 'fcbmPg13', 'fcbmP13', 'fcbm18', 'fcbm18sx', 'fcbm18pa', 'fcbm18sg', 'fcbm18pl', 'fcbmUnrated')")
        return value

    @field_validator('fco_rating')
    def fco_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fcoUnspecified', 'fcoI', 'fcoIia', 'fcoIib', 'fcoIi', 'fcoIii', 'fcoUnrated']):
            raise ValueError("must be one of enum values ('fcoUnspecified', 'fcoI', 'fcoIia', 'fcoIib', 'fcoIi', 'fcoIii', 'fcoUnrated')")
        return value

    @field_validator('fmoc_rating')
    def fmoc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fmocUnspecified', 'fmocU', 'fmoc10', 'fmoc12', 'fmoc16', 'fmoc18', 'fmocE', 'fmocUnrated']):
            raise ValueError("must be one of enum values ('fmocUnspecified', 'fmocU', 'fmoc10', 'fmoc12', 'fmoc16', 'fmoc18', 'fmocE', 'fmocUnrated')")
        return value

    @field_validator('fpb_rating')
    def fpb_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fpbUnspecified', 'fpbA', 'fpbPg', 'fpb79Pg', 'fpb1012Pg', 'fpb13', 'fpb16', 'fpb18', 'fpbX18', 'fpbXx', 'fpbUnrated', 'fpb10']):
            raise ValueError("must be one of enum values ('fpbUnspecified', 'fpbA', 'fpbPg', 'fpb79Pg', 'fpb1012Pg', 'fpb13', 'fpb16', 'fpb18', 'fpbX18', 'fpbXx', 'fpbUnrated', 'fpb10')")
        return value

    @field_validator('fpb_rating_reasons')
    def fpb_rating_reasons_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['fpbRatingReasonUnspecified', 'fpbBlasphemy', 'fpbLanguage', 'fpbNudity', 'fpbPrejudice', 'fpbSex', 'fpbViolence', 'fpbDrugs', 'fpbSexualViolence', 'fpbHorror', 'fpbCriminalTechniques', 'fpbImitativeActsTechniques']):
                raise ValueError("each list item must be one of ('fpbRatingReasonUnspecified', 'fpbBlasphemy', 'fpbLanguage', 'fpbNudity', 'fpbPrejudice', 'fpbSex', 'fpbViolence', 'fpbDrugs', 'fpbSexualViolence', 'fpbHorror', 'fpbCriminalTechniques', 'fpbImitativeActsTechniques')")
        return value

    @field_validator('fsk_rating')
    def fsk_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fskUnspecified', 'fsk0', 'fsk6', 'fsk12', 'fsk16', 'fsk18', 'fskUnrated']):
            raise ValueError("must be one of enum values ('fskUnspecified', 'fsk0', 'fsk6', 'fsk12', 'fsk16', 'fsk18', 'fskUnrated')")
        return value

    @field_validator('grfilm_rating')
    def grfilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['grfilmUnspecified', 'grfilmK', 'grfilmE', 'grfilmK12', 'grfilmK13', 'grfilmK15', 'grfilmK17', 'grfilmK18', 'grfilmUnrated']):
            raise ValueError("must be one of enum values ('grfilmUnspecified', 'grfilmK', 'grfilmE', 'grfilmK12', 'grfilmK13', 'grfilmK15', 'grfilmK17', 'grfilmK18', 'grfilmUnrated')")
        return value

    @field_validator('icaa_rating')
    def icaa_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['icaaUnspecified', 'icaaApta', 'icaa7', 'icaa12', 'icaa13', 'icaa16', 'icaa18', 'icaaX', 'icaaUnrated']):
            raise ValueError("must be one of enum values ('icaaUnspecified', 'icaaApta', 'icaa7', 'icaa12', 'icaa13', 'icaa16', 'icaa18', 'icaaX', 'icaaUnrated')")
        return value

    @field_validator('ifco_rating')
    def ifco_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ifcoUnspecified', 'ifcoG', 'ifcoPg', 'ifco12', 'ifco12a', 'ifco15', 'ifco15a', 'ifco16', 'ifco18', 'ifcoUnrated']):
            raise ValueError("must be one of enum values ('ifcoUnspecified', 'ifcoG', 'ifcoPg', 'ifco12', 'ifco12a', 'ifco15', 'ifco15a', 'ifco16', 'ifco18', 'ifcoUnrated')")
        return value

    @field_validator('ilfilm_rating')
    def ilfilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ilfilmUnspecified', 'ilfilmAa', 'ilfilm12', 'ilfilm14', 'ilfilm16', 'ilfilm18', 'ilfilmUnrated']):
            raise ValueError("must be one of enum values ('ilfilmUnspecified', 'ilfilmAa', 'ilfilm12', 'ilfilm14', 'ilfilm16', 'ilfilm18', 'ilfilmUnrated')")
        return value

    @field_validator('incaa_rating')
    def incaa_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['incaaUnspecified', 'incaaAtp', 'incaaSam13', 'incaaSam16', 'incaaSam18', 'incaaC', 'incaaUnrated']):
            raise ValueError("must be one of enum values ('incaaUnspecified', 'incaaAtp', 'incaaSam13', 'incaaSam16', 'incaaSam18', 'incaaC', 'incaaUnrated')")
        return value

    @field_validator('kfcb_rating')
    def kfcb_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['kfcbUnspecified', 'kfcbG', 'kfcbPg', 'kfcb16plus', 'kfcbR', 'kfcbUnrated']):
            raise ValueError("must be one of enum values ('kfcbUnspecified', 'kfcbG', 'kfcbPg', 'kfcb16plus', 'kfcbR', 'kfcbUnrated')")
        return value

    @field_validator('kijkwijzer_rating')
    def kijkwijzer_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['kijkwijzerUnspecified', 'kijkwijzerAl', 'kijkwijzer6', 'kijkwijzer9', 'kijkwijzer12', 'kijkwijzer16', 'kijkwijzer18', 'kijkwijzerUnrated']):
            raise ValueError("must be one of enum values ('kijkwijzerUnspecified', 'kijkwijzerAl', 'kijkwijzer6', 'kijkwijzer9', 'kijkwijzer12', 'kijkwijzer16', 'kijkwijzer18', 'kijkwijzerUnrated')")
        return value

    @field_validator('kmrb_rating')
    def kmrb_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['kmrbUnspecified', 'kmrbAll', 'kmrb12plus', 'kmrb15plus', 'kmrbTeenr', 'kmrbR', 'kmrbUnrated']):
            raise ValueError("must be one of enum values ('kmrbUnspecified', 'kmrbAll', 'kmrb12plus', 'kmrb15plus', 'kmrbTeenr', 'kmrbR', 'kmrbUnrated')")
        return value

    @field_validator('lsf_rating')
    def lsf_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['lsfUnspecified', 'lsfSu', 'lsfA', 'lsfBo', 'lsf13', 'lsfR', 'lsf17', 'lsfD', 'lsf21', 'lsfUnrated']):
            raise ValueError("must be one of enum values ('lsfUnspecified', 'lsfSu', 'lsfA', 'lsfBo', 'lsf13', 'lsfR', 'lsf17', 'lsfD', 'lsf21', 'lsfUnrated')")
        return value

    @field_validator('mccaa_rating')
    def mccaa_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mccaaUnspecified', 'mccaaU', 'mccaaPg', 'mccaa12a', 'mccaa12', 'mccaa14', 'mccaa15', 'mccaa16', 'mccaa18', 'mccaaUnrated']):
            raise ValueError("must be one of enum values ('mccaaUnspecified', 'mccaaU', 'mccaaPg', 'mccaa12a', 'mccaa12', 'mccaa14', 'mccaa15', 'mccaa16', 'mccaa18', 'mccaaUnrated')")
        return value

    @field_validator('mccyp_rating')
    def mccyp_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mccypUnspecified', 'mccypA', 'mccyp7', 'mccyp11', 'mccyp15', 'mccypUnrated']):
            raise ValueError("must be one of enum values ('mccypUnspecified', 'mccypA', 'mccyp7', 'mccyp11', 'mccyp15', 'mccypUnrated')")
        return value

    @field_validator('mcst_rating')
    def mcst_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mcstUnspecified', 'mcstP', 'mcst0', 'mcstC13', 'mcstC16', 'mcst16plus', 'mcstC18', 'mcstGPg', 'mcstUnrated']):
            raise ValueError("must be one of enum values ('mcstUnspecified', 'mcstP', 'mcst0', 'mcstC13', 'mcstC16', 'mcst16plus', 'mcstC18', 'mcstGPg', 'mcstUnrated')")
        return value

    @field_validator('mda_rating')
    def mda_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mdaUnspecified', 'mdaG', 'mdaPg', 'mdaPg13', 'mdaNc16', 'mdaM18', 'mdaR21', 'mdaUnrated']):
            raise ValueError("must be one of enum values ('mdaUnspecified', 'mdaG', 'mdaPg', 'mdaPg13', 'mdaNc16', 'mdaM18', 'mdaR21', 'mdaUnrated')")
        return value

    @field_validator('medietilsynet_rating')
    def medietilsynet_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['medietilsynetUnspecified', 'medietilsynetA', 'medietilsynet6', 'medietilsynet7', 'medietilsynet9', 'medietilsynet11', 'medietilsynet12', 'medietilsynet15', 'medietilsynet18', 'medietilsynetUnrated']):
            raise ValueError("must be one of enum values ('medietilsynetUnspecified', 'medietilsynetA', 'medietilsynet6', 'medietilsynet7', 'medietilsynet9', 'medietilsynet11', 'medietilsynet12', 'medietilsynet15', 'medietilsynet18', 'medietilsynetUnrated')")
        return value

    @field_validator('meku_rating')
    def meku_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mekuUnspecified', 'mekuS', 'meku7', 'meku12', 'meku16', 'meku18', 'mekuUnrated']):
            raise ValueError("must be one of enum values ('mekuUnspecified', 'mekuS', 'meku7', 'meku12', 'meku16', 'meku18', 'mekuUnrated')")
        return value

    @field_validator('mena_mpaa_rating')
    def mena_mpaa_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['menaMpaaUnspecified', 'menaMpaaG', 'menaMpaaPg', 'menaMpaaPg13', 'menaMpaaR', 'menaMpaaUnrated']):
            raise ValueError("must be one of enum values ('menaMpaaUnspecified', 'menaMpaaG', 'menaMpaaPg', 'menaMpaaPg13', 'menaMpaaR', 'menaMpaaUnrated')")
        return value

    @field_validator('mibac_rating')
    def mibac_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mibacUnspecified', 'mibacT', 'mibacVap', 'mibacVm6', 'mibacVm12', 'mibacVm14', 'mibacVm16', 'mibacVm18', 'mibacUnrated']):
            raise ValueError("must be one of enum values ('mibacUnspecified', 'mibacT', 'mibacVap', 'mibacVm6', 'mibacVm12', 'mibacVm14', 'mibacVm16', 'mibacVm18', 'mibacUnrated')")
        return value

    @field_validator('moc_rating')
    def moc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mocUnspecified', 'mocE', 'mocT', 'moc7', 'moc12', 'moc15', 'moc18', 'mocX', 'mocBanned', 'mocUnrated']):
            raise ValueError("must be one of enum values ('mocUnspecified', 'mocE', 'mocT', 'moc7', 'moc12', 'moc15', 'moc18', 'mocX', 'mocBanned', 'mocUnrated')")
        return value

    @field_validator('moctw_rating')
    def moctw_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['moctwUnspecified', 'moctwG', 'moctwP', 'moctwPg', 'moctwR', 'moctwUnrated', 'moctwR12', 'moctwR15']):
            raise ValueError("must be one of enum values ('moctwUnspecified', 'moctwG', 'moctwP', 'moctwPg', 'moctwR', 'moctwUnrated', 'moctwR12', 'moctwR15')")
        return value

    @field_validator('mpaa_rating')
    def mpaa_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mpaaUnspecified', 'mpaaG', 'mpaaPg', 'mpaaPg13', 'mpaaR', 'mpaaNc17', 'mpaaX', 'mpaaUnrated']):
            raise ValueError("must be one of enum values ('mpaaUnspecified', 'mpaaG', 'mpaaPg', 'mpaaPg13', 'mpaaR', 'mpaaNc17', 'mpaaX', 'mpaaUnrated')")
        return value

    @field_validator('mpaat_rating')
    def mpaat_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mpaatUnspecified', 'mpaatGb', 'mpaatRb']):
            raise ValueError("must be one of enum values ('mpaatUnspecified', 'mpaatGb', 'mpaatRb')")
        return value

    @field_validator('mtrcb_rating')
    def mtrcb_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mtrcbUnspecified', 'mtrcbG', 'mtrcbPg', 'mtrcbR13', 'mtrcbR16', 'mtrcbR18', 'mtrcbX', 'mtrcbUnrated']):
            raise ValueError("must be one of enum values ('mtrcbUnspecified', 'mtrcbG', 'mtrcbPg', 'mtrcbR13', 'mtrcbR16', 'mtrcbR18', 'mtrcbX', 'mtrcbUnrated')")
        return value

    @field_validator('nbc_rating')
    def nbc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['nbcUnspecified', 'nbcG', 'nbcPg', 'nbc12plus', 'nbc15plus', 'nbc18plus', 'nbc18plusr', 'nbcPu', 'nbcUnrated']):
            raise ValueError("must be one of enum values ('nbcUnspecified', 'nbcG', 'nbcPg', 'nbc12plus', 'nbc15plus', 'nbc18plus', 'nbc18plusr', 'nbcPu', 'nbcUnrated')")
        return value

    @field_validator('nbcpl_rating')
    def nbcpl_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['nbcplUnspecified', 'nbcplI', 'nbcplIi', 'nbcplIii', 'nbcplIv', 'nbcpl18plus', 'nbcplUnrated']):
            raise ValueError("must be one of enum values ('nbcplUnspecified', 'nbcplI', 'nbcplIi', 'nbcplIii', 'nbcplIv', 'nbcpl18plus', 'nbcplUnrated')")
        return value

    @field_validator('nfrc_rating')
    def nfrc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['nfrcUnspecified', 'nfrcA', 'nfrcB', 'nfrcC', 'nfrcD', 'nfrcX', 'nfrcUnrated']):
            raise ValueError("must be one of enum values ('nfrcUnspecified', 'nfrcA', 'nfrcB', 'nfrcC', 'nfrcD', 'nfrcX', 'nfrcUnrated')")
        return value

    @field_validator('nfvcb_rating')
    def nfvcb_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['nfvcbUnspecified', 'nfvcbG', 'nfvcbPg', 'nfvcb12', 'nfvcb12a', 'nfvcb15', 'nfvcb18', 'nfvcbRe', 'nfvcbUnrated']):
            raise ValueError("must be one of enum values ('nfvcbUnspecified', 'nfvcbG', 'nfvcbPg', 'nfvcb12', 'nfvcb12a', 'nfvcb15', 'nfvcb18', 'nfvcbRe', 'nfvcbUnrated')")
        return value

    @field_validator('nkclv_rating')
    def nkclv_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['nkclvUnspecified', 'nkclvU', 'nkclv7plus', 'nkclv12plus', 'nkclv16plus', 'nkclv18plus', 'nkclvUnrated']):
            raise ValueError("must be one of enum values ('nkclvUnspecified', 'nkclvU', 'nkclv7plus', 'nkclv12plus', 'nkclv16plus', 'nkclv18plus', 'nkclvUnrated')")
        return value

    @field_validator('nmc_rating')
    def nmc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['nmcUnspecified', 'nmcG', 'nmcPg', 'nmcPg13', 'nmcPg15', 'nmc15plus', 'nmc18plus', 'nmc18tc', 'nmcUnrated']):
            raise ValueError("must be one of enum values ('nmcUnspecified', 'nmcG', 'nmcPg', 'nmcPg13', 'nmcPg15', 'nmc15plus', 'nmc18plus', 'nmc18tc', 'nmcUnrated')")
        return value

    @field_validator('oflc_rating')
    def oflc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['oflcUnspecified', 'oflcG', 'oflcPg', 'oflcM', 'oflcR13', 'oflcR15', 'oflcR16', 'oflcR18', 'oflcUnrated', 'oflcRp13', 'oflcRp16', 'oflcRp18']):
            raise ValueError("must be one of enum values ('oflcUnspecified', 'oflcG', 'oflcPg', 'oflcM', 'oflcR13', 'oflcR15', 'oflcR16', 'oflcR18', 'oflcUnrated', 'oflcRp13', 'oflcRp16', 'oflcRp18')")
        return value

    @field_validator('pefilm_rating')
    def pefilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['pefilmUnspecified', 'pefilmPt', 'pefilmPg', 'pefilm14', 'pefilm18', 'pefilmUnrated']):
            raise ValueError("must be one of enum values ('pefilmUnspecified', 'pefilmPt', 'pefilmPg', 'pefilm14', 'pefilm18', 'pefilmUnrated')")
        return value

    @field_validator('rcnof_rating')
    def rcnof_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rcnofUnspecified', 'rcnofI', 'rcnofIi', 'rcnofIii', 'rcnofIv', 'rcnofV', 'rcnofVi', 'rcnofUnrated']):
            raise ValueError("must be one of enum values ('rcnofUnspecified', 'rcnofI', 'rcnofIi', 'rcnofIii', 'rcnofIv', 'rcnofV', 'rcnofVi', 'rcnofUnrated')")
        return value

    @field_validator('resorteviolencia_rating')
    def resorteviolencia_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['resorteviolenciaUnspecified', 'resorteviolenciaA', 'resorteviolenciaB', 'resorteviolenciaC', 'resorteviolenciaD', 'resorteviolenciaE', 'resorteviolenciaUnrated']):
            raise ValueError("must be one of enum values ('resorteviolenciaUnspecified', 'resorteviolenciaA', 'resorteviolenciaB', 'resorteviolenciaC', 'resorteviolenciaD', 'resorteviolenciaE', 'resorteviolenciaUnrated')")
        return value

    @field_validator('rtc_rating')
    def rtc_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rtcUnspecified', 'rtcAa', 'rtcA', 'rtcB', 'rtcB15', 'rtcC', 'rtcD', 'rtcUnrated']):
            raise ValueError("must be one of enum values ('rtcUnspecified', 'rtcAa', 'rtcA', 'rtcB', 'rtcB15', 'rtcC', 'rtcD', 'rtcUnrated')")
        return value

    @field_validator('rte_rating')
    def rte_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rteUnspecified', 'rteGa', 'rteCh', 'rtePs', 'rteMa', 'rteUnrated']):
            raise ValueError("must be one of enum values ('rteUnspecified', 'rteGa', 'rteCh', 'rtePs', 'rteMa', 'rteUnrated')")
        return value

    @field_validator('russia_rating')
    def russia_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['russiaUnspecified', 'russia0', 'russia6', 'russia12', 'russia16', 'russia18', 'russiaUnrated']):
            raise ValueError("must be one of enum values ('russiaUnspecified', 'russia0', 'russia6', 'russia12', 'russia16', 'russia18', 'russiaUnrated')")
        return value

    @field_validator('skfilm_rating')
    def skfilm_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['skfilmUnspecified', 'skfilmG', 'skfilmP2', 'skfilmP5', 'skfilmP8', 'skfilmUnrated']):
            raise ValueError("must be one of enum values ('skfilmUnspecified', 'skfilmG', 'skfilmP2', 'skfilmP5', 'skfilmP8', 'skfilmUnrated')")
        return value

    @field_validator('smais_rating')
    def smais_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['smaisUnspecified', 'smaisL', 'smais7', 'smais12', 'smais14', 'smais16', 'smais18', 'smaisUnrated']):
            raise ValueError("must be one of enum values ('smaisUnspecified', 'smaisL', 'smais7', 'smais12', 'smais14', 'smais16', 'smais18', 'smaisUnrated')")
        return value

    @field_validator('smsa_rating')
    def smsa_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['smsaUnspecified', 'smsaA', 'smsa7', 'smsa11', 'smsa15', 'smsaUnrated']):
            raise ValueError("must be one of enum values ('smsaUnspecified', 'smsaA', 'smsa7', 'smsa11', 'smsa15', 'smsaUnrated')")
        return value

    @field_validator('tvpg_rating')
    def tvpg_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['tvpgUnspecified', 'tvpgY', 'tvpgY7', 'tvpgY7Fv', 'tvpgG', 'tvpgPg', 'pg14', 'tvpgMa', 'tvpgUnrated']):
            raise ValueError("must be one of enum values ('tvpgUnspecified', 'tvpgY', 'tvpgY7', 'tvpgY7Fv', 'tvpgG', 'tvpgPg', 'pg14', 'tvpgMa', 'tvpgUnrated')")
        return value

    @field_validator('yt_rating')
    def yt_rating_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ytUnspecified', 'ytAgeRestricted']):
            raise ValueError("must be one of enum values ('ytUnspecified', 'ytAgeRestricted')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ContentRating from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ContentRating from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "acbRating": obj.get("acbRating"),
            "agcomRating": obj.get("agcomRating"),
            "anatelRating": obj.get("anatelRating"),
            "bbfcRating": obj.get("bbfcRating"),
            "bfvcRating": obj.get("bfvcRating"),
            "bmukkRating": obj.get("bmukkRating"),
            "catvRating": obj.get("catvRating"),
            "catvfrRating": obj.get("catvfrRating"),
            "cbfcRating": obj.get("cbfcRating"),
            "cccRating": obj.get("cccRating"),
            "cceRating": obj.get("cceRating"),
            "chfilmRating": obj.get("chfilmRating"),
            "chvrsRating": obj.get("chvrsRating"),
            "cicfRating": obj.get("cicfRating"),
            "cnaRating": obj.get("cnaRating"),
            "cncRating": obj.get("cncRating"),
            "csaRating": obj.get("csaRating"),
            "cscfRating": obj.get("cscfRating"),
            "czfilmRating": obj.get("czfilmRating"),
            "djctqRating": obj.get("djctqRating"),
            "djctqRatingReasons": obj.get("djctqRatingReasons"),
            "ecbmctRating": obj.get("ecbmctRating"),
            "eefilmRating": obj.get("eefilmRating"),
            "egfilmRating": obj.get("egfilmRating"),
            "eirinRating": obj.get("eirinRating"),
            "fcbmRating": obj.get("fcbmRating"),
            "fcoRating": obj.get("fcoRating"),
            "fmocRating": obj.get("fmocRating"),
            "fpbRating": obj.get("fpbRating"),
            "fpbRatingReasons": obj.get("fpbRatingReasons"),
            "fskRating": obj.get("fskRating"),
            "grfilmRating": obj.get("grfilmRating"),
            "icaaRating": obj.get("icaaRating"),
            "ifcoRating": obj.get("ifcoRating"),
            "ilfilmRating": obj.get("ilfilmRating"),
            "incaaRating": obj.get("incaaRating"),
            "kfcbRating": obj.get("kfcbRating"),
            "kijkwijzerRating": obj.get("kijkwijzerRating"),
            "kmrbRating": obj.get("kmrbRating"),
            "lsfRating": obj.get("lsfRating"),
            "mccaaRating": obj.get("mccaaRating"),
            "mccypRating": obj.get("mccypRating"),
            "mcstRating": obj.get("mcstRating"),
            "mdaRating": obj.get("mdaRating"),
            "medietilsynetRating": obj.get("medietilsynetRating"),
            "mekuRating": obj.get("mekuRating"),
            "menaMpaaRating": obj.get("menaMpaaRating"),
            "mibacRating": obj.get("mibacRating"),
            "mocRating": obj.get("mocRating"),
            "moctwRating": obj.get("moctwRating"),
            "mpaaRating": obj.get("mpaaRating"),
            "mpaatRating": obj.get("mpaatRating"),
            "mtrcbRating": obj.get("mtrcbRating"),
            "nbcRating": obj.get("nbcRating"),
            "nbcplRating": obj.get("nbcplRating"),
            "nfrcRating": obj.get("nfrcRating"),
            "nfvcbRating": obj.get("nfvcbRating"),
            "nkclvRating": obj.get("nkclvRating"),
            "nmcRating": obj.get("nmcRating"),
            "oflcRating": obj.get("oflcRating"),
            "pefilmRating": obj.get("pefilmRating"),
            "rcnofRating": obj.get("rcnofRating"),
            "resorteviolenciaRating": obj.get("resorteviolenciaRating"),
            "rtcRating": obj.get("rtcRating"),
            "rteRating": obj.get("rteRating"),
            "russiaRating": obj.get("russiaRating"),
            "skfilmRating": obj.get("skfilmRating"),
            "smaisRating": obj.get("smaisRating"),
            "smsaRating": obj.get("smsaRating"),
            "tvpgRating": obj.get("tvpgRating"),
            "ytRating": obj.get("ytRating")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from youtube_ti.models.invideo_branding import InvideoBranding

from youtube_ti.api_client import ApiClient, RequestSerialized
from youtube_ti.api_response import ApiResponse
from youtube_ti.rest import RESTResponseType


class WatermarksApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def youtube_watermarks_set(
        self,
        channel_id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        invideo_branding: Optional[InvideoBranding] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> None:
        """youtube_watermarks_set

        Allows upload of watermark image and setting it for a channel.

        :param channel_id: (required)
        :type channel_id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param invideo_branding:
        :type invideo_branding: InvideoBranding
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_watermarks_set_serialize(
            channel_id=channel_id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            invideo_branding=invideo_branding,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_watermarks_set_with_http_info(
        self,
        channel_id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        invideo_branding: Optional[InvideoBranding] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[None]:
        """youtube_watermarks_set

        Allows upload of watermark image and setting it for a channel.

        :param channel_id: (required)
        :type channel_id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param invideo_branding:
        :type invideo_branding: InvideoBranding
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_watermarks_set_serialize(
            channel_id=channel_id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            invideo_branding=invideo_branding,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_watermarks_set_without_preload_content(
        self,
        channel_id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        invideo_branding: Optional[InvideoBranding] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_watermarks_set

        Allows upload of watermark image and setting it for a channel.

        :param channel_id: (required)
        :type channel_id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param invideo_branding:
        :type invideo_branding: InvideoBranding
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_watermarks_set_serialize(
            channel_id=channel_id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            invideo_branding=invideo_branding,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_watermarks_set_serialize(
        self,
        channel_id,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        on_behalf_of_content_owner,
        invideo_branding,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if channel_id is not None:
            
            _query_params.append(('channelId', channel_id))
            
        if on_behalf_of_content_owner is not None:
            
            _query_params.append(('onBehalfOfContentOwner', on_behalf_of_content_owner))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if invideo_branding is not None:
            _body_params = invideo_branding



        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/octet-stream', 
                        'image/jpeg', 
                        'image/png'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/youtube/v3/watermarks/set',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def youtube_watermarks_unset(
        self,
        channel_id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> None:
        """youtube_watermarks_unset

        Allows removal of channel watermark.

        :param channel_id: (required)
        :type channel_id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_watermarks_unset_serialize(
            channel_id=channel_id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_watermarks_unset_with_http_info(
        self,
        channel_id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[None]:
        """youtube_watermarks_unset

        Allows removal of channel watermark.

        :param channel_id: (required)
        :type channel_id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_watermarks_unset_serialize(
            channel_id=channel_id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_watermarks_unset_without_preload_content(
        self,
        channel_id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_watermarks_unset

        Allows removal of channel watermark.

        :param channel_id: (required)
        :type channel_id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_watermarks_unset_serialize(
            channel_id=channel_id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_watermarks_unset_serialize(
        self,
        channel_id,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        on_behalf_of_content_owner,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if channel_id is not None:
            
            _query_params.append(('channelId', channel_id))
            
        if on_behalf_of_content_owner is not None:
            
            _query_params.append(('onBehalfOfContentOwner', on_behalf_of_content_owner))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/youtube/v3/watermarks/unset',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.comment_thread_snippet import CommentThreadSnippet

class TestCommentThreadSnippet(unittest.TestCase):
    """CommentThreadSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CommentThreadSnippet:
        """Test CommentThreadSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CommentThreadSnippet`
        """
        model = CommentThreadSnippet()
        if include_optional:
            return CommentThreadSnippet(
                can_reply = True,
                channel_id = '',
                is_public = True,
                top_level_comment = youtube_ti.models.comment.Comment(
                    etag = '', 
                    id = '', 
                    kind = 'youtube#comment', 
                    snippet = youtube_ti.models.comment_snippet.CommentSnippet(
                        author_channel_id = youtube_ti.models.comment_snippet_author_channel_id.CommentSnippetAuthorChannelId(
                            value = '', ), 
                        author_channel_url = '', 
                        author_display_name = '', 
                        author_profile_image_url = '', 
                        can_rate = True, 
                        channel_id = '', 
                        like_count = 56, 
                        moderation_status = 'published', 
                        parent_id = '', 
                        published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        text_display = '', 
                        text_original = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        video_id = '', 
                        viewer_rating = 'none', ), ),
                total_reply_count = 56,
                video_id = ''
            )
        else:
            return CommentThreadSnippet(
        )
        """

    def testCommentThreadSnippet(self):
        """Test CommentThreadSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.comment_snippet import CommentSnippet

class TestCommentSnippet(unittest.TestCase):
    """CommentSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CommentSnippet:
        """Test CommentSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CommentSnippet`
        """
        model = CommentSnippet()
        if include_optional:
            return CommentSnippet(
                author_channel_id = youtube_ti.models.comment_snippet_author_channel_id.CommentSnippetAuthorChannelId(
                    value = '', ),
                author_channel_url = '',
                author_display_name = '',
                author_profile_image_url = '',
                can_rate = True,
                channel_id = '',
                like_count = 56,
                moderation_status = 'published',
                parent_id = '',
                published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                text_display = '',
                text_original = '',
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                video_id = '',
                viewer_rating = 'none'
            )
        else:
            return CommentSnippet(
        )
        """

    def testCommentSnippet(self):
        """Test CommentSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.super_chat_event_snippet import SuperChatEventSnippet

class TestSuperChatEventSnippet(unittest.TestCase):
    """SuperChatEventSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SuperChatEventSnippet:
        """Test SuperChatEventSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SuperChatEventSnippet`
        """
        model = SuperChatEventSnippet()
        if include_optional:
            return SuperChatEventSnippet(
                amount_micros = '',
                channel_id = '',
                comment_text = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                currency = '',
                display_string = '',
                is_super_sticker_event = True,
                message_type = 56,
                super_sticker_metadata = youtube_ti.models.super_sticker_metadata.SuperStickerMetadata(
                    alt_text = '', 
                    alt_text_language = '', 
                    sticker_id = '', ),
                supporter_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                    channel_id = '', 
                    channel_url = '', 
                    display_name = '', 
                    profile_image_url = '', )
            )
        else:
            return SuperChatEventSnippet(
        )
        """

    def testSuperChatEventSnippet(self):
        """Test SuperChatEventSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
